@@ -1,5 +1,5 @@
-__version__ = "0.0.2"
-__keywords__ = ["vpn vpngate softether vpncmd cli api rpc commandline command"]
+__version__ = "0.1.1"
+__keywords__ = ["vpn vpngate softether vpncmd cli api rpc cmd commandline command"]
 
 
 if not __version__.endswith(".0"):
